@@ -17,9 +17,15 @@
 #include <QGridLayout>
 #include <QStringList>
 #include <QStringListModel>
-#include <QMaemo5ListPickSelector>
-#include <QMaemo5ValueButton>
-#include <QMaemo5InformationBox>
+#ifdef Q_WS_MAEMO_5
+    #include <QMaemo5ListPickSelector>
+    #include <QMaemo5ValueButton>
+    #include <QMaemo5InformationBox>
+#else
+    #include <QComboBox>
+    #include "Banner.h"
+#endif
+
 #include "global_defs.h"
 
 
@@ -31,6 +37,7 @@
 #define MIN_BUFFER_LEN_DEFAULT  30
 #define PRE_BUFFERING_DEFAULT    1
 #define SAVE_CREDENTIALS_DEFAULT 0
+#define HIDE_COVERART_DEFAULT 0
 #define ENABLE_SCROBBLING_DEFAULT 0
 #define ORIENTATION_DEFAULT 0
 #define PLAYLIST_LOADING_TO_DEFAULT 30
@@ -76,12 +83,22 @@ private:
 
     QCheckBox m_SaveCredentials; //checkbox to indicate whether the user login credentails should be stored (i.e., for auto-login)
 
+    QCheckBox m_HideCoverArt; //checkbox to indicate whether the coverart should be hidden in the Queue View (to free more space for track info).
+
     QStringList m_bitrateList; //list of available bitrate alternatives
 
+#ifdef Q_WS_MAEMO_5
+
     QMaemo5ValueButton m_PreferredBitrateBtn; //value type button for selecting the preferred bitrate
 
     QMaemo5ListPickSelector *m_pPreferredBitrateSelector; //pick selector associated with preferred bitrate value button
 
+#else
+
+    QComboBox m_PreferredBitrateCombo; //combo for selecting current bitrate
+
+#endif
+
     QGroupBox m_PlaylistOptions; //container for playlist related settings
 
     QGridLayout m_PlaylistOptionLayout;
@@ -102,22 +119,38 @@ private:
     QLabel m_MinBufferLenCaption;
     QLineEdit m_MinBufferLenInput;  //min. buffer length used (in secs)
 
+#ifdef Q_WS_MAEMO_5
+
     QMaemo5ValueButton m_UILangBtn; //value type button for selecting current UI language
 
+    QMaemo5ListPickSelector *m_pUILangSelector; //pick selector associated with UI language button
+
+#else
+
+    QComboBox m_UILangCombo; //combo for selecting current UI language
+
+#endif
+
     QStringList m_UILangList; //list of possible UI language values (e.g., English)
 
     QStringList m_UILangCodeList; //internal list of corresponding UI language codes (e.g., en for English)
 
-    QMaemo5ListPickSelector *m_pUILangSelector; //pick selector associated with UI language button
-
     QCheckBox m_PreBufferNextTrackSelection; //selected if automatic buffering of next track should be activated
 
     QStringList m_orientationList; //list of device orientation values
 
+#ifdef Q_WS_MAEMO_5
+
     QMaemo5ListPickSelector *m_pOrientationSelector; //pick selector associated with the orientation value button
 
     QMaemo5ValueButton m_OrientationBtn; //value type button for selecting desired screen orientation
 
+#else
+
+    QComboBox m_OrientationCombo; //combo box for selecting desired screen orientation
+
+#endif
+
     QLabel m_PlaylistLoadingTOCaption;
     QLineEdit m_PlaylistLoadingTOInput; //timeout value for playlist loading (in secs)
 
@@ -147,6 +180,8 @@ private:
 
     qint32 m_saveCredentials;
 
+    qint32 m_hideCoverart;
+
     QString m_strUserID;
 
     QString m_strUserPwd;
