@@ -1,20 +1,27 @@
 #ifndef IMAGECONTAINER_H
 #define IMAGECONTAINER_H
 
+#include <QObject>
 #include <QImage>
 
 namespace Spotify
 {
-    class ImageContainer
+    class ImageContainer : public QObject
     {
+        Q_OBJECT
+
     public:
-        ImageContainer();
+        ImageContainer(QObject* parent = 0);
         virtual void setImage( QImage image );
         virtual QImage getImage() const;
-        virtual QString getTypeName() { return "Generic Image Container"; }
 
     protected:
+
         QImage m_image;
+
+    signals:
+
+        void loaded();  //emitted when image assigned to the current imagecontainer instance
 };
 
 } // namespace Spotify
