@@ -37,38 +37,24 @@ namespace Spotify
 
             m_collaborative = sp_playlist_is_collaborative( m_playlist );
 
-            //if(sp_playlist_is_loaded( m_playlist ))
-            //{
-
-                // First time we get tracks for this playlist
-                if( m_tracks.count() == 0 )
+            // First time we get tracks for this playlist
+            if( m_tracks.count() == 0 )
+            {
+                for( int i = 0; i < m_numTracks; ++i )
                 {
-                    for( int i = 0; i < m_numTracks; ++i )
-                    {
-                        sp_track* track = sp_playlist_track( m_playlist, i );
-                        if( track )
-                        {
-                        	//if(sp_track_is_loaded( track ) )
-                        	//{
-                        		Spotify::Track* strack = new Spotify::Track( track, false, this );
-                        		m_tracks.append( strack );
-                                        m_tracksOriginal.append( strack );
-                        	//}
-                        }
-                        else
-                        {
-                        	m_tracks.append(NULL);
-                        }
-                    }
-
-                  }
-
-                m_isLoaded = sp_playlist_is_loaded(m_playlist);
-                if(m_isLoaded)
-                	emit loaded();
-            //}
-                return m_isLoaded;
+                    sp_track* track = sp_playlist_track( m_playlist, i );
+                    Spotify::Track* strack = new Spotify::Track( track, false, this );
+                    m_tracks.append( strack );
+                    m_tracksOriginal.append( strack );
                 }
+            }
+
+            m_isLoaded = sp_playlist_is_loaded(m_playlist);
+            if(m_isLoaded)
+                emit loaded();
+
+            return m_isLoaded;
+        }
     }
 
     void Playlist::updateName()
