@@ -89,8 +89,8 @@ void Spotify::Session::init(const sp_bitrate& bitrate)
 
     // Set config:
     m_config.api_version = SPOTIFY_API_VERSION;
-    m_config.cache_location = "tmp";
-    m_config.settings_location = "tmp";
+    m_config.cache_location = "";
+    m_config.settings_location = "";
     m_config.application_key = g_appkey;
     m_config.application_key_size = g_appkey_size;
     m_config.user_agent = "QSpot";
@@ -192,7 +192,7 @@ qint32 Spotify::Session::getBufferingPos()
 
 void Spotify::Session::setPlaying(bool playing)
 {
-    m_playing = playing;
+    m_buffering = playing;
 }
 
 void Spotify::Session::setNextTrackStartPos()
@@ -253,11 +253,11 @@ Spotify::Error Spotify::Session::login( QString username, QString password )
     m_error = sp_session_login( m_session, username.toUtf8(), password.toUtf8() );
     if( m_error.isError() )
     {
-        qDebug()<<"Not valid";
+        qDebug()<<"Login error";
         m_valid = false;
     }
     else
-    {
+    { //successful login, store credentials temporarily during session.
         m_username = QString(username);
         m_password = QString(password);
     }
@@ -265,8 +265,31 @@ Spotify::Error Spotify::Session::login( QString username, QString password )
     return m_error;
 }
 
+Spotify::Error Spotify::Session::reconnect()
+{
+    //Reconnects / re-logins current user to Spotify.
+    //Used in case network connection etc. is temporarily lost, and reconnect is required.
+
+    m_buffering = false; //no buffering as we are not logged in
+
+    m_error = sp_session_login( m_session, m_username.toUtf8(), m_password.toUtf8() );
+    if( m_error.isError() )
+    {
+        qDebug()<<"Login error (reconnect)";
+        m_valid = false;
+    }
+
+    return m_error;
+}
+
 void Spotify::Session::logout()
 {
+    //Logs out the current user from the Spotify service.
+    if(m_currentUser)
+    {
+        delete m_currentUser;
+        m_currentUser = NULL;
+    }
     sp_session_logout( m_session );
 }
 
@@ -316,7 +339,7 @@ void Spotify::Session::resetPlaybackMembers()
 
 Spotify::Error Spotify::Session::play( Spotify::Track* track, bool preBuffer )
 {
-    m_playing = false;
+    m_buffering = false;
     m_currentTrack = track;
     Spotify::Error error;
 
@@ -372,7 +395,7 @@ Spotify::Error Spotify::Session::play( Spotify::Track* track, bool preBuffer )
             m_playbackPos = 0;
             m_bufferedAmount = 0;
         }
-        m_playing = true;
+        m_buffering = true;
     }
     else
     {
@@ -401,16 +424,16 @@ Spotify::Error Spotify::Session::seek( qint32 pos )
 
 Spotify::Error Spotify::Session::stop()
 {
-    //stop playback (buffering) and unload the currently loaded track
+    //stop playback (buffering)
     Spotify::Error error;
 
-    if( m_playing )
+    if( m_buffering )
     {
         error = sp_session_player_play( m_session, false );
         if( !error.isError() )
         {
            // sp_session_player_unload( m_session );
-            m_playing = false;
+            m_buffering = false;
         }
     }
     return error;
@@ -434,21 +457,21 @@ Spotify::Error Spotify::Session::pauseResumeBuffering()
     Spotify::Error error;
 
     //playing (buffering) music data
-    if( m_playing )
+    if( m_buffering )
     { //pause buffering
         error = sp_session_player_play( m_session, false );
         if( !error.isError() )
         {
-            m_playing = false;
+            m_buffering = false;
         }
     }
     // buffering currently paused
-    else if( !m_playing && m_currentTrack->getTrack() && sp_track_is_loaded( m_currentTrack->getTrack() ) )
+    else if( !m_buffering && m_currentTrack->getTrack() && sp_track_is_loaded( m_currentTrack->getTrack() ) )
     { //resume buffering
         error = sp_session_player_play( m_session, true );
         if( !error.isError() )
         {
-             m_playing = true;
+             m_buffering = true;
         }
     }
     return error;
@@ -1213,7 +1236,8 @@ void Spotify::Session::loggedInWrapper( Spotify::Error error )
 
     // Let application know we're logged in (or not):
     m_valid = !error.isError();
-   m_currentUser = new Spotify::User( sp_session_user( m_session ) );
+    if(!m_currentUser)
+        m_currentUser = new Spotify::User( sp_session_user( m_session ) );
    qDebug() <<"User " + m_currentUser->getDisplayName() + " logged in..";
    emit loggedIn( error );
 }
@@ -1293,7 +1317,7 @@ int Spotify::Session::musicDeliveryWrapper( const sp_audioformat* format, const
 {
 
     // No data or invalid format/frames:
-    if (num_frames == 0 || !frames || !format || !m_playing)
+    if (num_frames == 0 || !frames || !format || !m_buffering)
         return 0;
 
     int bufSize = num_frames * sizeof(int16_t) * format->channels;
@@ -1367,7 +1391,7 @@ void Spotify::Session::playTokenLostWrapper( sp_session* session )
     //emit signal when playback token has been lost (e.g., same account logs in somewhere else)
     Q_UNUSED( session );
     emit playTokenLost();
-    m_playing = false;
+    m_buffering = false;
 }
 
 void Spotify::Session::logMessageCallback( sp_session* session, const char* message )
